@@ -5,7 +5,7 @@ from datetime import datetime, timedelta
 import requests
 
 from ..classes.programme import Programme
-from ..const import RESPONSE_OK
+from ..const import RESPONSE_OK, SKY_STATUS_LIVE
 from .const_it import (
     CHANNEL_IMAGE_URL,
     CHANNEL_URL,
@@ -96,6 +96,7 @@ class SkyQCountry:
                 episode,
                 imageUrl,
                 channelName,
+                SKY_STATUS_LIVE,
             )
             programmes.add(programme)
 
